#
# spec file for package perl-Gtk2
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define cpan_name Gtk2
Name:           perl-Gtk2
Version:        1.24992
Release:        59.2
Summary:        Perl interface to the 2.x series of the GTK+ library
License:        LGPL-2.1+
Group:          Development/Libraries/Perl
Url:            https://metacpan.org/pod/Gtk2
Source:         https://cpan.metacpan.org/authors/id/X/XA/XAOC/%{cpan_name}-%{version}.tar.gz
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  xorg-x11
BuildRequires:  xorg-x11-Xvfb
BuildRequires:  xorg-x11-server
BuildRequires:  perl(Cairo) >= 1.000
BuildRequires:  perl(ExtUtils::Depends) >= 0.300
BuildRequires:  perl(ExtUtils::PkgConfig) >= 1.030000
BuildRequires:  perl(Glib) >= 1.280
BuildRequires:  perl(Pango) >= 1.220
BuildRequires:  pkgconfig(gtk+-2.0)
Requires:       perl(Cairo) >= 1.000
Requires:       perl(ExtUtils::Depends) >= 0.300
Requires:       perl(ExtUtils::PkgConfig) >= 1.030000
Requires:       perl(Glib) >= 1.280
Requires:       perl(Pango) >= 1.220
Provides:       %{name}-devel = %{version}
%perl_requires

%description
The Gtk2 module allows a Perl developer to use the GTK+ graphical
user interface library. Find out more about GTK+ at https://gtk.org/

The GTK+ Reference Manual is also a handy companion when writing
Gtk applications in any language. The Perl bindings follow the
C API very closely, and the C reference documentation should be
considered the canonical source.

To discuss gtk2-perl, ask questions and flame/praise the authors,
join gtk-perl-list@gnome.org at lists.gnome.org.

Also have a look at the gtk2-perl website and sourceforge project
page, http://gtk2-perl.sourceforge.net/

%prep
%setup -q -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor OPTIMIZE="%{optflags}"
make %{?_smp_mflags} V=1

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%check
Xvfb :95 &
trap "kill $! || true" EXIT
sleep 5
DISPLAY=:95 make test %{?_smp_mflags} V=1

%files -f %{name}.files
%defattr(-,root,root)
%doc AUTHORS ChangeLog.pre-git LICENSE NEWS constants-* README TODO
%doc doctypes examples gdk.typemap Gtk2.exports gtk.typemap maps-* perl-Gtk2.doap xs_files-*

%changelog
* Tue May  9 2017 sor.alexei@meowr.ru
- Update to version 1.24992 (changes since 1.2498):
  * Rename an internal variable to avoid confusion.
  * Make the Gtk2::StatusIcon::position_menu tests more
    robust/lenient.
  * Fix typos in POD (bgo#760067).
  * Fix typos in POD (bgo#772333).
  ∗ Handle removing '.' from @INC for perl-5.26.0 compatibility.
  * Update FSF Address (RT#89038).
- Provide perl-Gtk2-devel as there are some header files in the
  package.
* Thu Feb 11 2016 sor.alexei@meowr.ru
- Update to 1.2498:
  * Add blurbs for the Gtk2::Pango::* POD/man pages.
* Fri Dec  4 2015 sor.alexei@meowr.ru
- Update to 1.2497:
  * Avoid a stack handling error in Gtk2::TreeModel::get on
    Perl >= 5.23.
  * Fix a test failure in t/GdkWindow.t; it occurs only on
    GTK+ >= 2.24.26 and < 2.24.29.
- Remove perl-Gtk2-fix-test-failure.patch: fixed upstream.
* Fri Aug 21 2015 sor.alexei@meowr.ru
- Update to 1.2496:
  * Avoid registering a GType for GConnectFlags if not needed.
  * MANIFEST: add missing gtk-demo files.
- Add perl-Gtk2-fix-test-failure.patch: fix a test failure in
  t/GdkWindow.t that occurs only on gtk+ >= 2.24.26 and < 2.24.29
  (bnc#932349).
- Spec cleanup.
* Fri Apr 24 2015 coolo@suse.com
- updated to 1.2495
  see /usr/share/doc/packages/perl-Gtk2/ChangeLog.pre-git
* Mon Jul 28 2014 coolo@suse.com
- updated to 1.2492
  * Fix compatibility with perl 5.20 and non-dot locales.
  * Disable some tests that are known to behave erratically in certain
  environments.  They are still available in the "xt" directory, but they will
  not be run by default.
  Overview of changes in Gtk2 1.2491
  ==================================
  * Fix a test failure in t/GdkPixbufLoader.t.
- removed perl-Gtk2-fix_GdkPixbufLoader_test.patch again
* Mon May 12 2014 vcizek@suse.com
- fix build with newer gdk-pixbuf
  * added perl-Gtk2-fix_GdkPixbufLoader_test.patch
* Sun Feb  9 2014 coolo@suse.com
- enable the test suite again
* Sun Feb  2 2014 zaitor@opensuse.org
- Update to version 1.249:
  + Eliminate test failures by using unique temp directories during
    testing.
- Disable testsuite since it still fails....
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.248
  * Avoid misusing the macro PL_na, thus preventing issues when Gtk2 is used in
  conjunction with certain XS modules, among them XML::Parser and
  String::Approx.
* Mon Jul  8 2013 coolo@suse.com
- updated to 1.247
  * Require Glib 1.280 for the fixes to custom signal marshalling.
  * Fix a test failure in t/GtkRecentChooser.t.
  * Created %%meta_merge which follows v2 of CPAN Meta Spec
  - %%meta_merge is used for generating metadata via
    ExtUtils::MakeMaker/CPAN::Meta
  * Improve the failure diagnostics of some tests
  * Fix two test failures.
  * Disable the correct potentially annoying test for GtkDnD.
  * Tell CPAN to some ignore POD fragments
  * Avoid trying to re-register a GType for GConnectFlags.
- remove perl-Gtk2-fix-GtkRecentChooser-test-fails.patch
* Thu Jan 31 2013 mlin@suse.com
- Add upstream patch perl-Gtk2-fix-GtkRecentChooser-test-fails.patch
  * Fixed GtkRecentChooser test fails with Gtk+ 2.24.12 (bgo#685865)
* Mon Jan 23 2012 vcizek@suse.com
- update to 1.242
  * Add gitweb link to old ChangeLog
  * Be compatible with perl 5.8.0 (Bugzilla bug #666227)
  * Gtk2::Widget: don't implement is_sensitive() twice
  * Disable a few potentially annoying tests
* Wed Nov 23 2011 vcizek@suse.com
- update to 1.241
  * Fix a test failure in t/GtkEntryBuffer.t
  * Fix a test failure in t/tied-objects.t
  * Add the missing NEWS entries from the stable branch.
  * Wrap missing gdk, gdk-pixbuf and gtk+ 2.12, 2.14, 2.16, 2.18, 2.20 and 2.22 API
  * Add Gtk2::Gdk::Image
  * Add Gtk2::Container->find_child_property and list_child_properties
  * Add Gtk2::Widget->find_style_property and list_style_properties
  * Add Gtk2::Gdk::Pixbuf->get_option
  * Add is_writable field to Gtk2::Gdk::PixbufFormat
  * Make Gtk2::FontButton->new and Gtk2::ColorButton->new more flexible
  * Accept format strings in Gtk2::MessageDialog->format_secondary_markup
  * In syntax check mode, do not call gtk_init
  * Improve the documentation in many places
* Thu Aug  4 2011 vcizek@novell.com
- update to 1.224
  fix a few test failures
  removed a patch (fixed in upstream)
  keep original tarball, no bzip2 anymore
* Fri Mar  4 2011 vcizek@novell.com
- update to 1.223
  * Test that Gtk2::Dialog's "response" signal is marshalled properly
- two tests-related patches are no longer necessary
* Mon Jan 31 2011 vcizek@novell.com
- temporary disabled two GtkBuilder tests.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Tue Nov  9 2010 coolo@novell.com
- remove tests that currently fail till a new upstream version comes up
  (mostly accelerator related)
* Fri Jul 16 2010 chris@computersalat.de
- recreated by cpanspec 1.78
  o fix deps
  o cleanup spec
* Fri Jul 16 2010 anicka@suse.cz
- update to 1.222
  * Make Gtk2::ListStore->remove()'s return value consistent on
  gtk+ 2.0
  * Fix some build and test failures.
* Sun Jan 10 2010 jengelh@medozas.de
- enable parallel build
* Mon Oct 12 2009 anicka@suse.cz
- add perl-Pango to Requires (bnc#546140)
* Tue Aug  4 2009 anicka@suse.cz
- update to 1.221
  * Properly wrap the binding for gtk_binding_entry_skip in version
  guards.
  * Fix some build and test failures.
* Mon Mar 23 2009 anicka@suse.cz
- update to 1.220
  * t/00.Gtk2.t: Don't fail if there is no valid DISPLAY.
  * gtk2perl.h: Remove the definitions for the custom pango GTypes.
    They now come from pango-perl.h.
  * bugfixes, test fixes
* Tue Jan 20 2009 anicka@suse.cz
- update to 1.202
  * xs/GtkTreeView.xs: Handle undef for callbacks correctly in
    Gtk2::TreeView::set_column_drag_function() and
    set_row_separator_func().
  * test fixes, documentation fixes
* Mon Oct  6 2008 anicka@suse.cz
- update to 1.200
  * xs/GtkDialog.xs: Use gtk_dialog_get_content_area and
  gtk_dialog_get_action_area if available to implement
  Gtk2::Dialog->get_content_area and Gtk2::Dialog->get_action_area,
  and fallback to direct struct access otherwise.  Deprecate
  Gtk2::Dialog->vbox and Gtk2::Dialog->action_area.
  * bug fixes, test fixes
* Thu Jun 19 2008 anicka@suse.cz
- update to 1.183
  * xs/GtkAdjustment.xs: Improve the documentation for the
  accessors.
  * xs/GtkWidget.xs: Document why signal_chain_from_overridden
  doesn't quite work when used in a size-request handler.
  * t/GtkRecentManager.t: Fix test failures due to the asynchronous
  nature of the manager's add_item().
  * xs/GdkProperty.xs: Overload '!=' for GdkAtoms.
  * xs/GdkWindow.xs: Add documentation for Gtk2::Gdk::Window::new.
  * xs/GdkWindow.xs (SvGdkWindowAttrReal): Use sv_2bool instead of
  SvUV to convert override_redirect values.
  * xs/GtkTreeModel.xs (gtk2perl_tree_model_iter_has_child): Accept
  all the usual boolean values for the return value of
  ITER_HAS_CHILD.
  * t/PangoLayout.t: Fix test failure on newer pango versions.
  * xs/GtkTreeView.xs: Describe the return values of
  get_visible_range and get_tooltip_context.
  * xs/GtkTreeModel.xs: In the POD section about tree iterators, add
  a paragraph explaining how data put into iterators needs to be
  kept alive by the model.
  * xs/GdkDisplay.xs: Allow undef for the display name parameter of
  Gtk2::Gdk::Display::open.
* Wed Apr  9 2008 anicka@suse.cz
- update to 1.182
  * xs/GtkScaleButton.xs: NULL-terminate the icon list passed to
  gtk_scale_button_new and gtk_scale_button_set_icons.
  * xs/GtkBuildable.xs (gtk2perl_buildable_custom_tag_start): Don't
  declare variables after expressions.
  * Makefile.PL: Depend on ExtUtils::Depends 0.300 and thereby void
  the need for the find_extra_libs stuff.
  * Gtk2/t/PangoCairo.t: Fix test failures, mostly on MSWin32
  and cygwin.
  * Makefile.PL: Trap exceptions thrown by EU::PkgConfig->find.
  When one occurs, exit with status 0 to indicate to CPAN testers
  that their system isn't supported.
* Mon Mar 17 2008 anicka@suse.cz
- update to 1.181
  * t/GtkBuildableIface.t: Fix test failure on gtk+ < 2.12.
  * Makefile.PL: Remove the no_index specification from EXTRA_META
  because the YAML implementations currently in use don't seem to
  support this syntax yet.
  * t/GtkTreeView.t: Fix remaining test failures.
  * xs/PangoLayout.xs: Wrap pango_layout_set_height and
  pango_layout_get_height.
  * xs/PangoTypes.xs (Gtk2::Pango::extents_to_pixel): Change the
  names of the arguments from "ink_rect, logical_rect" to
  "inclusive, nearest" as suggested by upstream.
  * xs/PangoLayout.xs: Wrap pango_layout_iter_get_layout and make
  use of pango_layout_iter_copy if available.
  * xs/PangoRenderer.xs: Wrap pango_renderer_get_layout and
  pango_renderer_get_layout_line.
  * t/GtkTreeView.t: Hopefully fix some test failures involving a
  wrong number of tests run by having every callback with tests
  run only once.
* Tue Jan 15 2008 anicka@suse.cz
- update to 1.164
  * xs/PangoLayout.xs: Work around what appears to be a bug in
  ExtUtils::ParseXS' xsubpp (used by default in perl 5.10.0) for
  the pango_layout_line_x_to_index xsub: manually handle output
  arguments, i.e. dont't rely on OUTLIST.  This should fix the
  "Modification of a read-only value attempted" issue.
  * xs/GdkPixbuf.xs: Fix the signature docs for get_file_info(),
  suggested by Kevin Ryde.  Also add a brief description of the
  function.
  * t/GtkIconTheme.t (list_contexts test): Fix test failure.
  * bugfixes, test fixes
* Wed Nov 21 2007 anicka@suse.cz
- update to 1.162
  * Gtk2.pm (Gtk2::Builder::_do_connect): Don't use the qw//
    operator to qoute a flag value as it seems to cause parse
    failures on some perls.
* Fri Nov  9 2007 anicka@suse.cz
- update to 1.161
  * bugfixes, test fixes
* Thu Oct 25 2007 anicka@suse.cz
- update to 1.160
  * xs/GtkStatusIcon.xs: Make the x, y arguments to
    Gtk2::StatusIcon::position_menu optional.
  * xs/PangoAttributes.xs: Bless the array used to represent
    PangoColor so it becomes possible to call methods on it.
    Introduce some stack fiddling so you can use
    Gtk2::Pango::Color::to_string as a method and a class
    function.
  * xs/GtkBuilder.xs: Document the $builder->connect_signals
    ($user_data, $object) way of connecting signals.
  * xs/GtkCellRenderer.xs: Mortalize all SVs we put on the stack.
    In the past, we had to be careful not to cause destruction of
    pre-existing C objects, but that's not necessary anymore.
  * xs/GdkPixbuf.xs: Really plug the leaks in
    Gtk2::Gdk::Pixbuf::render_pixmap_and_mask() and
    render_pixmap_and_mask_for_colormap().
  * bugfixes, test fixes
- temporarily disable GdkKeys.t to avoid failing builds
* Tue Aug 21 2007 ro@suse.de
- update to 1.146 to fix test failures
* Thu Jul 12 2007 anicka@suse.cz
- temporarily disable some tests failing with gtk2 2.11.5
  (they seem to be wrong anyway)
* Mon Jul  9 2007 anicka@suse.cz
- update to 1.145
  * xs/GtkAboutDialog.xs: Hide the AboutDialog on any reponse.
  * xs/GdkPixbuf.xs: Plug reference leaks on the pixmap and bitmap
  returned from Gtk2::Gdk::Pixbuf::render_pixmap_and_mask() and
  render_pixmap_and_mask_for_colormap(). Also add a couple of
  FIXMEs.
  * xs/GtkIconView.xs: Supply default values for scroll_to_path.
  * xs/GtkTreeStore.xs: Make sure Gtk2::ListStore's and
  Gtk2::TreeStore's move_before() and move_after() accept undef
  for the position parameter.
  * test fixes
- remove last patch (fixed in upstream)
* Mon Jul  2 2007 jw@suse.de
- added gtk-demo next to examples.
* Thu Jun 21 2007 anicka@suse.cz
- disable one wrong test in GtkIconTheme.t
* Wed Mar 14 2007 anicka@suse.cz
- update to 1.144
  * t/GtkEditable.t, xs/GtkEditbale.xs: fix string encoding problems
  in the insert-text signal marshaller.
* Mon Feb 26 2007 anicka@suse.cz
- update to 1.143
  * Gtk2.pm, t/GtkTreeModelSort.t, xs/GtkTreeModelSort.xs: Make
    sure calling get() on a Gtk2::TreeModelSort resolves to
    Gtk2::TreeModel::get if appropriate, and, to keep backwards
    compatibility, to Glib::Object::get otherwise.
  * t/GtkTreeModelSort.t, xs/GtkTreeModelSort.xs: fix copy and
    paste error that made
    gtk_tree_model_sort_convert_child_iter_to_iter() unusable.
- enable one test fixed in upstream
* Thu Jan 25 2007 anicka@suse.cz
- update to 1.142
  * t/GtkIconView.t, xs/GtkIconView.xs: Fix the path handling in
    Gtk2::IconView::get_selected_items.  Previously, the returned
    paths were pointing to dead memory and any attempt to use them
    caused havoc.
  * xs/GtkRecentManager.xs: Add more documentation for the
    Gtk2::RecentManager::add_item and Gtk2::RecentManager::add_full
    methods; define the needed keys for the hashref to be passed
    to the add_full method.
  * GtkTreeSortable.xs: Don't segfault in the GET_SORT_COLUMN_ID
    marshaller if any of the output parameter pointers is NULL.
- enable test fixed in upstream
* Thu Dec 21 2006 anicka@suse.cz
- update to 1.141
  * t/PangoCairo.t, xs/PangoCairo.xs: Also allow using method
    calling semantics for pango_cairo_context_*.
  * fixes in documentation and tests
- enable tests fixed in upstream
* Sat Sep 16 2006 anicka@suse.de
- disable GtkIconView.t because it hangs on ppc64 machines
  (#206001)
* Wed Sep 13 2006 anicka@suse.cz
- add xorg-x11-Xvfb, xorg-x11, xorg-x11-server to BuildRequires
- disable some tests that randomly fail
* Tue Sep 12 2006 anicka@suse.cz
- update to 1.140
  * Don't call Gtk2::Gdk::Threads::init on a non-threading perl.
  * added support for more GTK objects
  * require Cairo.pm
  * bugfixes, new testsuites
* Fri Aug 18 2006 aj@suse.de
- Reduce BuildRequires.
* Fri Jul 21 2006 anicka@suse.cz
- update to 1.122
  * bugfixes and fixes to tests added
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 anicka@suse.cz
- update to 1.102
* Fri Nov 11 2005 anicka@suse.cz
- update to 1.101
* Mon Aug  1 2005 mjancar@suse.cz
- update to 1.083
* Thu Jul 21 2005 anicka@suse.cz
- add perl-Glib to Requires (#95905)
* Fri Jan 21 2005 ro@suse.de
- update to 1.072
* Tue Nov  2 2004 mcihar@suse.cz
- initial packaging
